@@ -97,7 +97,7 @@ class CreateChatCompletionResponse(TypedDict):
 
 
 class ChatCompletionMessageToolCallChunkFunction(TypedDict):
-    name: str
+    name: Optional[str]
     arguments: str
 
 
@@ -118,12 +118,12 @@ class ChatCompletionStreamResponseDeltaFunctionCall(TypedDict):
 
 
 class ChatCompletionStreamResponseDelta(TypedDict):
-    content: NotRequired[str]
+    content: NotRequired[Optional[str]]
     function_call: NotRequired[
-        ChatCompletionStreamResponseDeltaFunctionCall
+        Optional[ChatCompletionStreamResponseDeltaFunctionCall]
     ]  # DEPRECATED
-    tool_calls: NotRequired[List[ChatCompletionMessageToolCallChunk]]
-    role: NotRequired[Literal["system", "user", "assistant", "tool"]]
+    tool_calls: NotRequired[Optional[List[ChatCompletionMessageToolCallChunk]]]
+    role: NotRequired[Optional[Literal["system", "user", "assistant", "tool"]]]
 
 
 class ChatCompletionStreamResponseChoice(TypedDict):
@@ -132,6 +132,7 @@ class ChatCompletionStreamResponseChoice(TypedDict):
         ChatCompletionStreamResponseDelta, ChatCompletionStreamResponseDeltaEmpty
     ]
     finish_reason: Optional[Literal["stop", "length", "tool_calls", "function_call"]]
+    logprobs: NotRequired[Optional[CompletionLogprobs]]
 
 
 class CreateChatCompletionStreamResponse(TypedDict):
